/*
** File: vxw_entry.c  
** Project: VxWorks ADB3 monolithic driver entry point
** Purpose: Driver parameters
**
** (C) Copyright Alpha Data 2010
*/

#include "df.h"
#include "dfvxworks.h"

#include "adb3Drv.h"

static DfPciCompatibleId g_pciCompatibleIds[] = {
  {
    { 0x4144U, 0xadb3U, 0x4144U, 0U, 0U }, /* ADB3-based models */
    DF_PCI_MATCH_VENDOR | DF_PCI_MATCH_DEVICE | DF_PCI_MATCH_SUBVENDOR
  },
  DF_PCI_COMPATIBLE_ID_END
};

static DfPciCompatibleId g_legacyPciCompatibleIds[] = {
  {
    { 0x10b5U, 0x9656U, 0x4144U, 0U, 0U }, /* PCI9656-based models */
    DF_PCI_MATCH_VENDOR | DF_PCI_MATCH_DEVICE | DF_PCI_MATCH_SUBVENDOR
  },
  DF_PCI_COMPATIBLE_ID_END
};

/* Entry point for when built as downloadable module */
STATUS
adb3DrvStart(
  int debugLevel,
  int bLegacyHardware)
{
#if defined(ADB3_VXBUS)
  return dfVxbEntry(debugLevel, "adb3", g_pciCompatibleIds, g_legacyPciCompatibleIds, bLegacyHardware ? TRUE : FALSE);
#else
  return dfVxwLegacyEntry(debugLevel, "adb3", g_pciCompatibleIds, g_legacyPciCompatibleIds, bLegacyHardware ? TRUE : FALSE);
#endif
}

/* Entry point with component parameters, used when building into kernel */
STATUS
adb3DrvCompStart(
  int debugLevel,
  int bLegacyHardware,
  BOOL bEnableVpdWrite,
  BOOL bPciAddress64Bit,
  unsigned int numCommonBuffer,
  unsigned int commonBufferSize,
  unsigned int commonBufferAlign)
{
  extern unsigned int adb3DrvEnableVpdWrite;
  extern unsigned int adb3DrvPciAddress64Bit;
  extern unsigned int adb3DrvPrimaryCommonBufferCount;
  extern unsigned int adb3DrvPrimaryCommonBufferAlignment;
  extern unsigned int adb3DrvPrimaryCommonBufferSizeLow;

  adb3DrvEnableVpdWrite = (unsigned int)bEnableVpdWrite;
  adb3DrvPciAddress64Bit = (unsigned int)bPciAddress64Bit;
  adb3DrvPrimaryCommonBufferCount = numCommonBuffer;
  adb3DrvPrimaryCommonBufferAlignment = commonBufferAlign;
  adb3DrvPrimaryCommonBufferSizeLow = commonBufferSize;
  
  return adb3DrvStart(debugLevel, bLegacyHardware);
}

STATUS
adb3DrvStop(
  int debugLevel)
{
#if defined(ADB3_VXBUS)
  dfVxbExit();
#else
  dfVxwLegacyExit();
#endif
  return OK;
}
